﻿using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace ConsoleApplication.cvs
{
    /// <summary>
    /// コンビニ決済申込要求サンプル
    /// </summary>
    public partial class CLI_CvsAuthorize
    {
        public virtual void Exec()
        {
            /**
             * コンビニエンスストアの分類を指定
             * 
             * セブンイレブン                   ：　"sej"
             * ファミリーマート、ローソンその他 ：　"econ"
             * その他                           ：　"other"　（サークルKサンクス、デイリーヤマザキ、ヤマザキデイリーストアー、タイムリー、ミニストップ）
             */
            String serviceOptionType = "sej";
            /**
             * 取引ID
             */
            String orderId = "dummy" + System.DateTime.Now.ToString("HHmmssfff");
            /**
             * 支払金額
             */
            String amount = "1000";
            /**
             * 氏名1(姓)
             */
            String lastName = "顧客姓";
            /**
             * 氏名2（名）
             */
            String firstName = "顧客名";
            /**
             * 電話番号
             * (1)決済請求（共通）：
             * 電話番号の上２桁が次の場合、successを返します。
             * "09", "08", "07", "06", "05"
             * 上記以外の場合、failureを返します。
             * 
             * (2)決済取消（Other）：
             * 電話番号の上2桁が次の場合、successを返します。
             * "06", "05"
             * 上記以外の場合、failureを返します。
             */
            String telNumber = "05-1234-5678";
            /**
             * 支払期限
             */
            String paymentLimit = System.DateTime.Now.AddDays(5).ToString("yyyy/MM/dd");

            /**
             * 要求電文パラメータ値の指定
             */
            CvsAuthorizeRequestDto requestData = new CvsAuthorizeRequestDto();
            requestData.OrderId = orderId;
            requestData.Amount = amount;
            requestData.Name1 = lastName;
            requestData.Name2 = firstName;
            requestData.ServiceOptionType = serviceOptionType;
            requestData.TelNo = telNumber;
            requestData.PayLimit = paymentLimit;
            //※現在はリザーブパラメータのため無条件に "0" を設定して下さい。
            requestData.PaymentType = "0";


            /**
             * 実行と結果表示  
            */
            Transaction tran = new Transaction();
            CvsAuthorizeResponseDto responseData = (CvsAuthorizeResponseDto)tran.Execute(requestData);

            System.Console.WriteLine("<< REQUEST >>");
            System.Console.WriteLine("Order ID:" + requestData.OrderId);
            System.Console.WriteLine("Service Option Type:" + requestData.ServiceOptionType);
            System.Console.WriteLine("Amount:" + requestData.Amount);
            System.Console.WriteLine("Name1:" + requestData.Name1);
            System.Console.WriteLine("Name2:" + requestData.Name2);
            System.Console.WriteLine("Tel No:" + requestData.TelNo);
            System.Console.WriteLine("Payment Limit:" + requestData.PayLimit);

            System.Console.WriteLine("<< RESPONSE >>");
            System.Console.WriteLine("MStatus:" + responseData.Mstatus);
            System.Console.WriteLine("Message:" + responseData.MerrMsg);
            System.Console.WriteLine("Result Code:" + responseData.VResultCode);
            System.Console.WriteLine("Receipt No:" + responseData.ReceiptNo);
            System.Console.WriteLine("Haraikomi URL:" + responseData.HaraikomiUrl);
        }
    }
}
