﻿using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace ConsoleApplication.mpi
{
    /// <summary>
    /// 3Dセキュアカード連携 申込要求サンプル
    /// </summary>
    public partial class CLI_MpiAuthorize
    {
        public virtual void Exec()
        {
            /**
             * オプションタイプ
             * 1. MPIサービスのみ                         : mpi-none
             * 2. 完全認証                                : mpi-complete
             * 3. 通常認証（カード会社リスク負担）       ： mpi-company
             * 4. 通常認証（カード会社、加盟店リスク負担）: mpi-merchant
             * 
             */
            String serviceOptionType = "mpi-company";

            /**
             * 取引ID
             */
            String orderId = "dummy" + System.DateTime.Now.ToString("HHmmssfff");

            /**
             * 決済金額
             */
            String amount = "10";

            /**
             * トークン
             */
            String token = "0a812412-682c-4dad-8a5d-720caf23bca0";

            // /**
            //  * カード番号
            //  */
            // String cardNumber = "4111-1111-1111-1111";
            // /**
            //  * カード有効期限
            //  */
            // String cardExpire = "12/19";

            /**
             * HTTP User-Agent（消費者ブラウザ）
             * （実際はアプリケーションサーバから取得）
             */
            String httpUserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
            /**
             * HTTP Accept（消費者ブラウザ）
             * （実際はアプリケーションサーバから取得）
             */
            String httpAccept = "text/*;q=0.3, text/html;q=0.7";

            /**
             * 要求電文パラメータ値の指定
             */
            MpiAuthorizeRequestDto requestData = new MpiAuthorizeRequestDto();
            requestData.ServiceOptionType = serviceOptionType;
            requestData.OrderId = orderId;
            requestData.Amount = amount;
            requestData.Token = token;
            // requestData.CardNumber = cardNumber;
            // requestData.CardExpire = cardExpire;
            requestData.HttpUserAgent = httpUserAgent;
            requestData.HttpAccept = httpAccept;

            /**
             * 実行と結果表示 
             */
            Transaction tran = new Transaction();
            MpiAuthorizeResponseDto responseData = (MpiAuthorizeResponseDto)tran.Execute(requestData);

            System.Console.WriteLine("<< REQUEST >>");
            System.Console.WriteLine("Order ID:" + requestData.OrderId);
            System.Console.WriteLine("WithCapture:" + requestData.WithCapture);
            System.Console.WriteLine("Amount:" + requestData.Amount);
            System.Console.WriteLine("Token:" + requestData.Token);
            // System.Console.WriteLine("Card Number:" + requestData.CardNumber);
            // System.Console.WriteLine("Card Expired Date:" + requestData.CardExpire);

            System.Console.WriteLine("<< RESPONSE >>");
            System.Console.WriteLine("MStatus:" + responseData.Mstatus);
            System.Console.WriteLine("Message:" + responseData.MerrMsg);
            System.Console.WriteLine("Result Code:" + responseData.VResultCode);
            System.Console.WriteLine("Response Contents:" + responseData.ResResponseContents);
        }
    }
}
