using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace ConsoleApplication.paynowid
{
    /// <summary>PayNowId(カード決済＋会員入会)処理用サーブレット</summary>
    public class CLI_PayNowIdEntryAndCardCommand
    {
        /// <summary>コマンドテスト用メインメソッド</summary>
        public void Exec()
        {
            //---------------------------------
            // テスト用リクエスト電文項目設定  
            //---------------------------------
            // 取引ID(自動生成)
            String orderId = "dummy" + DateTime.Now.ToString("HHmmssfff");
            // 与信方法(同時売上実施の有無)
            String withCapture = "false";
            // 支払金額
            String amount = "10";
            // カード番号
            // String cardNumber = "4111-1111-1111-1111";
            // カード有効期限
            // String cardExpire = "12/16";
            // 支払方法
            String jpo = "10";
            // セキュリティコード
            // String securityCode = "1234";
            // トークン
            String token = "0a812412-682c-4dad-8a5d-720caf23bca0";
            // 会員ID
            String accountId = "TestAccountIdsd234";
            //// 課金グループID設定
            String groupId = "merchant4";
            //// 課金開始日設定
            String startDate = "20130930";
            //// 課金終了日設定
            String endDate = "20140930";
            //// 都度／初回課金金額設定
            String oneTimeAmount = "10";
            //// 継続課金金額設定
            String recurringAmount = "10";

            //---------------------------------
            // リクエスト DTO 設定  
            //---------------------------------
            var reqDto = new CardAuthorizeRequestDto
                {
                    OrderId = orderId, // オーダーIDの設定
                    WithCapture = withCapture, // 与信方法の設定
                    Amount = amount, // 金額の設定
                    // CardNumber = cardNumber, // カード番号の設定
                    // CardExpire = cardExpire, // カード有効期限の設定
                    Jpo = jpo, // ペイメントオプション(支払方法・回数)の設定
                    // SecurityCode = securityCode, // セキュリティコード設定
                    Token = token, // トークン設定
                    AccountId = accountId, // 会員ID設定
                    GroupId = groupId, // 課金グループID設定
                    StartDate = startDate, // 課金開始日設定
                    EndDate = endDate, // 課金終了日設定
                    OneTimeAmount = oneTimeAmount, // 都度／初回課金金額設定
                    RecurringAmount = recurringAmount // 継続課金金額設定
                };

            //---------------------------------
            // 決済実行と結果表示  
            //---------------------------------

            try
            {
                var tran = new Transaction();
                var resDto = (CardAuthorizeResponseDto) tran.Execute(reqDto);
                var payNowIdRes = resDto.PayNowIdResponse;

                // リクエストとレスポンスを実行コンソール上で表示する
                Console.WriteLine("*- PayNowId(Authorize) -*");

                Console.WriteLine("<< REQUEST >>");
                Console.WriteLine("ServiceType:" + reqDto.ServiceType);
                Console.WriteLine("Order ID:" + orderId);
                Console.WriteLine("WithCapture:" + withCapture);
                Console.WriteLine("Amount:" + amount);
                // Console.WriteLine("Card Number:" + cardNumber);
                // Console.WriteLine("Card Expired Date:" + cardExpire);
                Console.WriteLine("JPO:" + jpo);
                // Console.WriteLine("Security Code(CVV2):" + securityCode);
                Console.WriteLine("Token:" + token);
                Console.WriteLine("Account ID:" + accountId);
                Console.WriteLine("Group ID:" + groupId);
                Console.WriteLine("Start Date:" + startDate);
                Console.WriteLine("End Date:" + endDate);
                Console.WriteLine("OneTimeAmount:" + oneTimeAmount);
                Console.WriteLine("RecurringAmount:" + recurringAmount);

                Console.WriteLine("<< RESPONSE >>");
                Console.WriteLine("Status:" + resDto.Mstatus);
                Console.WriteLine("PayNowId Status:" + ((payNowIdRes != null) ? payNowIdRes.Status : "I do not know status because of PayNowIdResponse is null."));
                Console.WriteLine("Message:" + resDto.MerrMsg);
                Console.WriteLine("Result Code:" + resDto.VResultCode);
                Console.WriteLine("Auth Code:" + resDto.ResAuthCode);
                Console.WriteLine("Reference Number:" + resDto.ResReturnReferenceNumber);

            }
            catch (Exception ex)
            {
                Console.WriteLine("Exception Occured !");
                Console.WriteLine("Exception Message " + ex.Message);
            }
        }
    }
}