using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace ConsoleApplication.paynowid
{
    /// <summary>PayNowId(継続課金削除)処理用サーブレット</summary>
    public class CLI_PayNowIdRecurringDeleteCommand
    {
        /// <summary>コマンドテスト用メインメソッド</summary>
        public void Exec()
        {

            // ---------------------------------
            // テスト用リクエスト電文項目設定
            // ---------------------------------
            // 会員ID
            String accountId = "TestAccountId";
            // 課金グループID設定
            String groupId = "merchant4";
            // 課金終了日設定
            String endDate = "20140930";
            // 課金自動終了フラグ
            String finalCharge = "0";

            // ---------------------------------
            // リクエスト DTO 設定
            // ---------------------------------
            var reqDto = new RecurringDeleteRequestDto
                {
                    AccountId = accountId, // 会員ID設定
                    GroupId = groupId, // 課金グループID設定
                    EndDate = endDate, // 課金終了日設定
                    FinalCharge = finalCharge // 課金自動終了フラグ
                };

            // ---------------------------------
            // 処理実行と結果表示
            // ---------------------------------
            try
            {
                var tran = new Transaction();
                var resDto = (RecurringDeleteResponseDto) tran.Execute(reqDto);

                // リクエストとレスポンスを実行コンソール上で表示する
                Console.WriteLine("*- PayNowId(Delete) -*");

                Console.WriteLine("<< REQUEST >>");
                Console.WriteLine("ServiceType:" + reqDto.ServiceType);
                Console.WriteLine("Account ID:" + accountId);
                Console.WriteLine("Group ID:" + groupId);
                Console.WriteLine("End Date:" + endDate);
                Console.WriteLine("FinalCharge:" + finalCharge);

                Console.WriteLine("<< RESPONSE >>");
                Console.WriteLine("PayNowId Status:" + resDto.PayNowIdResponse.Status);
                Console.WriteLine("Message:" + resDto.MerrMsg);
                Console.WriteLine("Result Code:" + resDto.VResultCode);
                Console.WriteLine("PayNowId ProcId:" + resDto.PayNowIdResponse.ProcessId);

            }
            catch (Exception ex)
            {
                Console.WriteLine("Exception Occured !");
                Console.WriteLine("Exception Message " + ex.Message);
            }
        }
    }
}