﻿using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;
using System;

namespace ConsoleApplication.virtualacc
{
    /// <summary>
    /// 銀行振込決済 決済要求サンプル
    /// </summary>
    class CLI_VirtualaccAuthorize
    {
        public virtual void Exec()
        {
            // 取引ID(自動生成)
            String orderId = "dummy" + System.DateTime.Now.ToString("HHmmssfff");

            // 支払金額
            String amount = "10";

            // 口座振込人名
            String entryTransferName = "テストタロウ";

            // 口座振込番号
            String entryTransferNumber = "００００１";

            // 振込期限
            String transferExpiredDate = "";

            // 口座管理方式
            // 実口座 : MdkServiceConstants.VACC_ACCOUNT_MANAGE_TYPE_REAL
            // バーチャル口座 : MdkServiceConstants.VACC_ACCOUNT_MANAGE_TYPE_VIRTUAL
            String accountManageType = MdkServiceConstants.VACC_ACCOUNT_MANAGE_TYPE_REAL;

            // 支店コード・口座番号は口座管理号式がバーチャル口座の場合のみ設定
            // 支店コード
            String branchCode = "";

            // 口座番号
            String accountNumber = "";

            // サービスオプションタイプ
            // りそな : MdkServiceConstants.VACC_RESONA
            String serviceOptionType = MdkServiceConstants.VACC_RESONA;

            /**
             * 要求電文パラメータ値の指定
             */
            var requestData = new VirtualaccAuthorizeRequestDto();
            requestData.OrderId = orderId;
            requestData.Amount = amount;
            requestData.EntryTransferName = entryTransferName;
            requestData.EntryTransferNumber = entryTransferNumber;
            requestData.TransferExpiredDate = transferExpiredDate;
            requestData.AccountManageType = accountManageType;
            requestData.BranchCode = branchCode;
            requestData.AccountNumber = accountNumber;
            requestData.ServiceOptionType = serviceOptionType;

            /**
             * 実行と結果表示  
            */
            var tran = new Transaction();
            var responseData = (VirtualaccAuthorizeResponseDto)tran.Execute(requestData);

            System.Console.WriteLine("<< REQUEST >>");
            System.Console.WriteLine("Order ID:" + requestData.OrderId);
            System.Console.WriteLine("Amount:" + requestData.Amount);
            System.Console.WriteLine("Entry Transfer Name:" + requestData.EntryTransferName);
            System.Console.WriteLine("Entry Transfer Number:" + requestData.EntryTransferNumber);
            System.Console.WriteLine("Transfer Expired Date:" + requestData.TransferExpiredDate);
            System.Console.WriteLine("Account ManageType:" + requestData.AccountManageType);
            System.Console.WriteLine("Branch Code:" + requestData.BranchCode);
            System.Console.WriteLine("Account Number:" + requestData.AccountNumber);

            System.Console.WriteLine("<< RESPONSE >>");
            System.Console.WriteLine("Order Id:" + responseData.OrderId);
            System.Console.WriteLine("MStatus:" + responseData.Mstatus);
            System.Console.WriteLine("Message:" + responseData.MerrMsg);
            System.Console.WriteLine("Result Code:" + responseData.VResultCode);
            System.Console.WriteLine("Transfer Name:" + responseData.TransferName);
            System.Console.WriteLine("Bank Name:" + responseData.BankName);
            System.Console.WriteLine("Bank Code:" + responseData.BankCode);
            System.Console.WriteLine("Branch Name:" + responseData.BranchName);
            System.Console.WriteLine("Branch Code:" + responseData.BranchCode);
            System.Console.WriteLine("Account Type: " + responseData.AccountType);
            System.Console.WriteLine("Account Number:" + responseData.AccountNumber);
            System.Console.WriteLine("Account Name:" + responseData.AccountName);
        }
    }
}
