﻿using System;
using System.Data;
using System.Configuration;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml;

namespace MdkSampleDotNet
{
    public class Utils
    {
        private static String _filePath = null;

        public static void setFilePath(String filePath)
        {
            _filePath = filePath;
        }
        public static String getXPath(String xPath)
        {
            XmlDocument xmlDoc = new XmlDocument();
            xmlDoc.Load(_filePath);
            XmlNodeList nodes = xmlDoc.SelectNodes(xPath);
            XmlNode node = nodes.Item(0);
            return node.InnerText;
        }

        private static readonly DateTime Jan1st1970 = new DateTime(1970, 1, 1, 0, 0, 0, DateTimeKind.Utc);

        public static long CurrentTimeMillis()
        {
            return (long)(DateTime.UtcNow - Jan1st1970).TotalMilliseconds;
        }

        protected string GetIPAddress(HttpContext currentContext)
        {
            string ipAddress = currentContext.Request.ServerVariables["HTTP_X_FORWARDED_FOR"];

            if (!string.IsNullOrEmpty(ipAddress))
            {
                string[] addresses = ipAddress.Split(',');
                if (addresses.Length != 0)
                {
                    return addresses[0];
                }
            }

            return currentContext.Request.ServerVariables["REMOTE_ADDR"];
        }

        /// <summary>
        /// 日時（文字列）を表示用に編集する。
        ///     
        /// 例）
        /// 日時が「20130425」（8桁）の場合、「2013-04-25」
        /// 日時が「20130425103758」（14桁）の場合、「2013-04-25 10:37:58」
        /// 日時が「20130425103758741」（17桁）の場合、「2013-04-25 10:37:58.741」
        /// </summary>
        /// <param name="str">
        /// @return </param>
        public static String formatDateTime(String str)
        {
            string dateFormat08 = "{0}-{1}-{2}"; // yyyy-mm-ddフォーマット
            string dateFormat14 = "{0}-{1}-{2} {3}:{4}:{5}"; // yyyy-mm-dd hh:mi:ssフォーマット
            string dateFormat17 = "{0}-{1}-{2} {3}:{4}:{5}.{6}"; // yyyy-mm-dd hh:mi:ss.sssフォーマット
            string result = "";

            string sy = ""; // 年
            string sm = ""; // 月
            string sd = ""; // 日
            string sh = ""; // 時
            string si = ""; // 分
            string ss = ""; // 秒
            string sss = ""; // 秒以下

            if (!String.IsNullOrEmpty(str)) {
                switch (str.Length)
                {
                    case 8:
                        sy = str.Substring(0, 4);
                        sm = str.Substring(4, 2);
                        sd = str.Substring(6, 2);
                        result = String.Format(dateFormat08, sy, sm, sd);
                        break;
                    case 14:
                        sy = str.Substring(0, 4);
                        sm = str.Substring(4, 2);
                        sd = str.Substring(6, 2);
                        sh = str.Substring(8, 2);
                        si = str.Substring(10, 2);
                        ss = str.Substring(12, 2);
                        result = String.Format(dateFormat14, sy, sm, sd, sh, si, ss);
                        break;
                    case 17:
                        sy = str.Substring(0, 4);
                        sm = str.Substring(4, 2);
                        sd = str.Substring(6, 2);
                        sh = str.Substring(8, 2);
                        si = str.Substring(10, 2);
                        ss = str.Substring(12, 2);
                        sss = str.Substring(14, 3);
                        result = String.Format(dateFormat17, sy, sm, sd, sh, si, ss, sss);
                        break;
                    default:
                        result = str;
                        break;
                }
            }

            return result;
        }

        /// <summary>
        /// デコードするEncodingを指定して値を取得する
        /// </summary>
        /// <param name="request"></param>
        /// <param name="key"></param>
        /// <param name="enc"></param>
        /// <returns></returns>
        public static string GetRequestParameter(HttpRequest request, string key, Encoding enc)
        {
            string query = new Uri(request.Url.AbsoluteUri).Query;
            query = query.Replace("?", "");
            string[] reqParams = query.Split('&');
            for (int i = 0; i < reqParams.Length; i++)
            {
                string[] keyVal = reqParams[i].Split('=');

                if (keyVal[0] == key)
                {
                    return HttpUtility.UrlDecode(keyVal[1], enc);
                }
            }

            return "";
        }

        /// <summary>
        /// UTF8でデコードして値を取得する
        /// </summary>
        /// <param name="request"></param>
        /// <param name="key"></param>
        /// <param name="enc"></param>
        /// <returns></returns>
        public static string GetRequestParameter(HttpRequest request, string key)
        {
            return GetRequestParameter(request, key, Encoding.UTF8);
        }
    }
}
