﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using jp.veritrans.tercerog.mdk.dto;
using jp.veritrans.tercerog.mdk;

namespace MdkSampleDotNet.alipay
{
    public partial class Authorize : System.Web.UI.Page
    {
        /// <summary>
        /// 初期表示イベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                orderId.Text = "dummy" + Utils.CurrentTimeMillis();
                amount.Text = Request.QueryString["price"];

                string commodityNameStr = Request["commodityName"];
                if (commodityNameStr == null)
                {
                    commodityName.Text = "新製品";
                }

                string commodityDescriptionStr = Request["commodityDescription"];
                if (commodityDescriptionStr == null)
                {
                    commodityDescriptionStr = "新製品詳細";
                }
                commodityDescription.Text = commodityDescriptionStr;
                hidCommodityDescription.Value = commodityDescriptionStr;

                string commodityIdStr = Request["commodityId"];
                if (commodityIdStr == null)
                {
                    commodityIdStr = "";
                }
                commodityId.Text = commodityIdStr;
                hidCommodityId.Value = commodityIdStr;

                string successUrlStr = Request["successUrl"];
                if (successUrlStr == null)
                {
                    successUrlStr = Utils.getXPath(SampleConstants.ALIPAY_SUCCESS_URL);
                }
                successUrl.Text = successUrlStr;
                hidSuccessUrl.Value = successUrlStr;

                string errorUrlStr = Request["errorUrl"];
                if (errorUrlStr == null)
                {
                    errorUrlStr = Utils.getXPath(SampleConstants.ALIPAY_ERROR_URL);
                }
                errorUrl.Text = errorUrlStr;
                hidErrorUrl.Value = errorUrlStr;
            }
        }

        /// <summary>
        /// 取引ID更新ボタンイベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnReplaceOrderId_Click(object sender, EventArgs e)
        {
            // HiddenField更新
            hidCommodityId.Value = commodityId.Text;
            hidCommodityDescription.Value = commodityDescription.Text;
            hidSuccessUrl.Value = successUrl.Text;
            hidErrorUrl.Value = errorUrl.Text;

            orderId.Text = "dummy" + Utils.CurrentTimeMillis();
        }

        /// <summary>
        /// 購入ボタンイベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnSubmit_Click(object sender, EventArgs e)
        {
            // HiddenField更新
            hidCommodityId.Value = commodityId.Text;
            hidCommodityDescription.Value = commodityDescription.Text;
            hidSuccessUrl.Value = successUrl.Text;
            hidErrorUrl.Value = errorUrl.Text;

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 取引IDの取得
            String paramOrderId = orderId.Text;
            // 金額の取得
            String paramAmount = amount.Text;
            // 外貨の取得
            String paramCurrency = currency.SelectedValue;
            // 決済種別の取得
            String paramPayType = payType.SelectedValue;
            // ユーザ識別コードの取得
            String paramIdentityCode = identityCode.Text;
            // 決済完了時URLの取得
            String paramSuccessUrl = successUrl.Text;
            // 決済エラー時URLの取得
            String paramErrorUrl = errorUrl.Text;
            // 商品名の取得
            String paramCommodityName = commodityName.Text;
            // 商品詳細の取得
            String paramCommodityDescription = commodityDescription.Text;
            // 商品IDの取得
            String paramCommodityId = commodityId.Text;

            String dummyRequest = MerchantContext.Config.GetValue(MerchantConfig.DUMMY_REQUEST);

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            if (String.IsNullOrEmpty(paramOrderId))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font><br/><br/>";
                return;
            }
            if (!IsNumber(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>不正項目：金額は数値で入力しなければなりません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramCurrency))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：通貨が指定されていません</b></font><br/><br/>";
                return;
            }
            if ("1".Equals(dummyRequest) && "CNY".Equals(paramCurrency) && Int64.Parse(paramAmount) < 100)
            {
                errorMessage.Text = "<font color='#ff0000'><b>不正項目：金額には100以上の値を指定してください</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramSuccessUrl) && "0".Equals(paramPayType))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：決済完了時URLが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramErrorUrl) && "0".Equals(paramPayType))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：決済エラー時URLが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramCommodityName))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：商品名が指定されていません</b></font><br/><br/>";
                return;
            }

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 画面入力値を実行クラスに渡すためにセッションに設定します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            Session["paramOrderId"] = paramOrderId;
            Session["paramAmount"] = paramAmount;
            Session["paramCurrency"] = paramCurrency;
            Session["paramPayType"] = paramPayType;
            Session["paramIdentityCode"] = paramIdentityCode;
            Session["paramCommodityName"] = paramCommodityName;
            Session["paramCommodityDescription"] = paramCommodityDescription;
            Session["paramCommodityId"] = paramCommodityId;
            Session["paramSuccessUrl"] = paramSuccessUrl;
            Session["paramErrorUrl"] = paramErrorUrl;

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 実行＆結果画面を表示します
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            Response.Redirect("./AuthorizeExec.aspx", true);
        }
        /// <summary>
        /// 引数が数値であるかを確認。
        /// </summary>
        /// <param name="strNum">確認する文字列</param>
        /// <returns>数値の場合はtrueを返す</returns>
        private bool IsNumber(string strNum)
        {
            double dNullable;

            return double.TryParse(
                strNum,
                System.Globalization.NumberStyles.Any,
                null,
                out dNullable
            );
        }
    }
}
