﻿using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.paynowid
{
    public partial class EntryAndCardExec : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 与信方法の取得
            var withCapture = (Session["withCapture"] != null ? Session["withCapture"].ToString() : "");
            // 取引IDの取得
            var orderId = (Session["orderId"] != null ? Session["orderId"].ToString() : null);
            // 金額の取得
            var amount = (Session["amount"] != null ? Session["amount"].ToString() : null);
            // トークンの取得
            var token = (Session["token"] != null ? Session["token"].ToString() : null);
            // 支払方法の取得
            var jpo1 = (Session["jpo1"] != null ? Session["jpo1"].ToString() : null);
            // 支払回数の取得
            var jpo2 = (Session["jpo2"] != null ? Session["jpo2"].ToString() : null);
            // 会員IDの取得
            var accountId = (Session["accountId"] != null ? Session["accountId"].ToString() : null);
            // 課金グループIDの取得
            var groupId = (Session["groupId"] != null ? Session["groupId"].ToString() : null);
            // 課金開始日の取得
            var startDate = (Session["startDate"] != null ? Session["startDate"].ToString() : null);
            // 課金終了日の取得
            var endDate = (Session["endDate"] != null ? Session["endDate"].ToString() : null);
            // 都度／初回課金金額の取得
            var oneTimeAmount = (Session["oneTimeAmount"] != null ? Session["oneTimeAmount"].ToString() : null);
            // 継続課金金額の取得
            var recurringAmount = (Session["recurringAmount"] != null ? Session["recurringAmount"].ToString() : null);

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            String warning = null;
            if (String.IsNullOrEmpty(orderId))
            {
                warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
            }
            else if (String.IsNullOrEmpty(amount))
            {
                warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
            }

            if (!string.IsNullOrEmpty(warning))
            {
                Session["warning"] = warning;
                Response.Redirect("./EntryAndCard.aspx", true);
                return;
            }

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var reqDto = new CardAuthorizeRequestDto
                {
                    OrderId = orderId, // オーダーIDの設定
                    Amount = amount, // 金額の設定
                    Token = token, // トークンの設定
                    AccountId = accountId // 会員IDの設定
                };
            if (!string.IsNullOrEmpty(groupId))
            {
                reqDto.GroupId = groupId; // 課金グループIDの設定
                reqDto.StartDate = startDate; // 課金開始日の設定
                reqDto.EndDate = endDate; // 課金終了日の設定
                reqDto.OneTimeAmount = oneTimeAmount; // 都度／初回課金金額の設定
                reqDto.RecurringAmount = recurringAmount; // 継続課金金額の設定                
            }

            
            // ペイメントオプション(支払方法・回数)の設定
            String jpo = null;
            if ("10" == jpo1 || "80" == jpo1)
            {
                jpo = jpo1;
            }
            else if ("61" == jpo1 && jpo2 != null)
            {
                jpo = jpo1 + "C" + jpo2;
            }
            if (jpo != null) reqDto.Jpo = jpo;
            // 与信方法によって、売上フラグを設定
            if ("1" == withCapture) reqDto.WithCapture = "true";

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var tran = new Transaction();
            var resDto = (CardAuthorizeResponseDto)tran.Execute(reqDto);

            OrderId.Text = resDto.OrderId;
            MStatus.Text = resDto.Mstatus;
            VResultCode.Text = resDto.VResultCode;
            MErrMsg.Text = resDto.MerrMsg;

            if (resDto.PayNowIdResponse != null)
            {
                PayNowIdStatus.Text = resDto.PayNowIdResponse.Status;
            }
        }
    }
}
