﻿using System;
using System.Collections.Generic;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;
using MdkSampleDotNet;

namespace web.paynowid
{
    public partial class Recurring : System.Web.UI.Page
    {

        private CardInfo[] _cardInfos;
        private RecurringCharge[] _recurringChages;

        protected void Page_Load(object sender, EventArgs e)
        {
            ErrorMessage.Text = null;

            if (!IsPostBack)
            {
                if (CardSelect.DataSource == null)
                {
                    var dataSource = new Dictionary<String, String> { { "", "新しいカードを登録する" } };
                    CardSelect.DataValueField = "Key";
                    CardSelect.DataTextField = "Value";
                    CardSelect.DataSource = dataSource;
                    CardSelect.DataBind();
                }
                TokenApiKey.Text = Utils.getXPath(SampleConstants.TOKEN_API_KEY);
                TokenApiUrl.Text = Utils.getXPath(SampleConstants.TOKEN_API_URL);
                if (String.IsNullOrEmpty(TokenApiUrl.Text))
                {
                    var uri = new Uri(MerchantContext.Config.GetValue(MerchantConfig.SERVER_URL));
                    TokenApiUrl.Text = uri.ToString().TrimEnd('/') + "/4gtoken";
                }
            }

        }

        protected void Select_Click(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 課金処理モードの取得
            String chargeMode = ChargeMode.SelectedValue;
            // 会員IDの取得
            String accountId = AccountId.Text;
            // 課金グループIDの取得
            String groupId = GroupId.Text;
            // 課金開始日の取得
            String startDate = StartDate.Text;
            // 課金終了日の取得
            String endDate = EndDate.Text;
            // 都度／初回課金金額の取得
            String oneTimeAmount = OneTimeOut.Text;
            // 継続課金金額の取得
            String amount = Amount.Text;
            // カード選択の取得
            String cardSelect = CardSelect.SelectedValue;
            // トークンの取得
            String token = Token.Value;

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (String.IsNullOrEmpty(accountId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                return;
            }
            // 課金開始日
            if (chargeMode != "1" && !String.IsNullOrEmpty(startDate))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>課金開始日は指定できません</b></font>";
                return;
            }
            // 課金グループID
            if (String.IsNullOrEmpty(groupId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：課金グループIDが指定されていません</b></font>";
                return;
            }

            if (!String.IsNullOrEmpty(chargeMode)) Session["chargeMode"] = chargeMode;
            Session["accountId"] = accountId;
            Session["groupId"] = groupId;
            Session["startDate"] = startDate;
            Session["endDate"] = endDate;
            Session["oneTimeAmount"] = (!String.IsNullOrEmpty(oneTimeAmount)) ? oneTimeAmount : null;
            Session["amount"] = (!String.IsNullOrEmpty(amount)) ? amount : null;
            Session["cardSelect"] = cardSelect;
            Session["token"] = token;

            Response.Redirect("./RecurringExec.aspx", true);

        }

        protected void GetCardInfos_Click(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員IDの取得
            String accountId = AccountId.Text;

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (String.IsNullOrEmpty(accountId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                return;
            }

            // カード情報取得

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var reqDto = new CardInfoGetRequestDto { AccountId = accountId };

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var tran = new Transaction();
            var resDto = (CardInfoGetResponseDto)tran.Execute(reqDto);

            if (resDto.Mstatus != "success")
            {
                ErrorMessage.Text = string.Format("<font color='#ff0000'><b>{0}</b></font>", resDto.MerrMsg);
                CardSelect.DataSource = new Dictionary<String, String>();
                CardSelect.DataBind();
                return;
            }

            // 課金情報取得

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var recurringGetRequestDto = new RecurringGetRequestDto { AccountId = accountId };
            var recurringGetResponseDto = (RecurringGetResponseDto)tran.Execute(recurringGetRequestDto);

            if (
                recurringGetResponseDto.PayNowIdResponse.Status == "success" && 
                recurringGetResponseDto.PayNowIdResponse.Account.RecurringCharge != null &&
                recurringGetResponseDto.PayNowIdResponse.Account.RecurringCharge.Length > 0)
            {
                _recurringChages = recurringGetResponseDto.PayNowIdResponse.Account.RecurringCharge;
            }


            var dataSource = new Dictionary<String, String> { { "", "新しいカードを登録する" } };
            _cardInfos = resDto.PayNowIdResponse.Account.CardInfo;

            // カード情報分繰り返す
            if (_cardInfos != null)
            {
                foreach (var cardInfo in _cardInfos)
                {
                    String inUseIds = String.Empty;
                    if (_recurringChages != null)
                    {
                        RecurringCharge[] inUse = Array.FindAll(_recurringChages, 
                            charge => charge.CardId == cardInfo.CardId);
                        foreach (var recurringCharge in inUse)
                        {
                            inUseIds += recurringCharge.GroupId + ",";
                        }
                    }
                    dataSource.Add(cardInfo.CardId,
                                   inUseIds != ""
                                       ? String.Format("{0}：{1} ({2})", cardInfo.CardNumber, cardInfo.CardExpire, inUseIds)
                                       : String.Format("{0}：{1}", cardInfo.CardNumber, cardInfo.CardExpire));
                }
            }
            CardSelect.DataValueField = "Key";
            CardSelect.DataTextField = "Value";
            CardSelect.DataSource = dataSource;
            CardSelect.DataBind();

            Session["cardInfos"] = _cardInfos;
            if (Session["cardSelect"] != null)
            {
                Session.Remove("cardSelect");
            }


        }
    }
}
