﻿using System;
using System.Collections.Generic;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.paynowid
{
    public partial class RecurringTerminate : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            ErrorMessage.Text = null;
        }

        protected void GetRecurring_Click(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員IDの取得
            String accountId = AccountId.Text;

            // 継続課金情報取得　//

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (String.IsNullOrEmpty(accountId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                return;
            }

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var reqDto = new RecurringGetRequestDto {AccountId = accountId};

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var tran = new Transaction();
            var resDto = (RecurringGetResponseDto) tran.Execute(reqDto);

            if (resDto.Mstatus != "success")
            {
                ErrorMessage.Text = string.Format("<font color='#ff0000'><b>{0}</b></font>", resDto.MerrMsg);
                return;
            }

            var dataSource = new Dictionary<string, string>();
            if (resDto.PayNowIdResponse.Account != null)
            {
                // カード情報
                CardInfo[] cardInfos = resDto.PayNowIdResponse.Account.CardInfo;
                // 会員課金情報
                RecurringCharge[] recurringCharges = resDto.PayNowIdResponse.Account.RecurringCharge;
                if (recurringCharges != null)
                {
                    foreach (var recurringCharge in recurringCharges)
                    {
                        CardInfo tempCardInfo = GetCardInfo(recurringCharge.CardId, cardInfos);
                        dataSource.Add(recurringCharge.GroupId,
                                       string.Format("{0}：{1}：{2}", recurringCharge.GroupId, tempCardInfo.CardNumber,
                                                     tempCardInfo.CardExpire));
                    }
                }
            }
            GroupId.DataValueField = "Key";
            GroupId.DataTextField = "Value";
            GroupId.DataSource = dataSource;
            GroupId.DataBind();

        }

        protected void Submit_Click(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員IDの取得
            String accountId = AccountId.Text;
            // グループID
            String groupId = GroupId.SelectedValue;
            // 課金終了日の取得
            String endDate = EndDate.Text;
            // 課金自動終了フラグ
            String finalCharge = (FinalCharge.Checked) ? "1" : "";


            // カード削除処理  //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (string.IsNullOrEmpty(accountId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                return;
            }
            // 課金グループID
            if (string.IsNullOrEmpty(groupId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：課金グループIDが指定されていません</b></font>";
                return;
            }


            Session["accountId"] = accountId;
            Session["endDate"] = (!String.IsNullOrEmpty(endDate)) ? endDate : null;
            Session["groupId"] = groupId;
            Session["finalCharge"] = (!String.IsNullOrEmpty(finalCharge)) ? finalCharge : null;

            Response.Redirect("./RecurringTerminateExec.aspx", true);

        }

        /**
         * * カード情報からカードIDに対応する情報を取得する*/
        private CardInfo GetCardInfo(String cardId, CardInfo[] cardInfos)
        {
            for (int i = 0; i < cardInfos.Length; i++)
            {
                if (cardId == cardInfos[i].CardId)
                {
                    return cardInfos[i];
                }
            }
            var cardInfo = new CardInfo {CardNumber = "", CardExpire = ""};
            return cardInfo;
        }

    }
}
