﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using jp.veritrans.tercerog.mdk.dto;
using jp.veritrans.tercerog.mdk;

namespace MdkSampleDotNet.upop
{
    public partial class Authorize : System.Web.UI.Page
    {
        /// <summary>
        /// 初期表示イベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                orderId.Text = "dummy" + Utils.CurrentTimeMillis();
                amount.Text = Request.QueryString["price"];
                termUrl.Value = Utils.getXPath(SampleConstants.UPOP_TERM_URL);
                customerIp.Value = GetIPAddress();
            }
        }

        /// <summary>
        /// 取引ID更新ボタンイベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnReplaceOrderId_Click(object sender, EventArgs e)
        {
            orderId.Text = "dummy" + Utils.CurrentTimeMillis();
        }

        /// <summary>
        /// 購入ボタンイベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnSubmit_Click(object sender, EventArgs e)
        {
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 取引ID
            String paramOrderId = orderId.Text;
            // 支払金額
            String paramAmount = amount.Text;
            // ターミナルURL
            String paramTermUrl = termUrl.Value;
            // カスタマーIP
            String paramCustomerIp = customerIp.Value;
            // 与信売上
            String paramWithCapture = withCapture.SelectedValue;

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            if (String.IsNullOrEmpty(paramOrderId))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font><br/><br/>";
                return;
            }
            if (!IsNumber(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>金額は数値で入力しなければなりません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramTermUrl))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：ターミナルURLが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramCustomerIp))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：カスタマーIPが指定されていません</b></font><br/><br/>";
                return;
            }

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 画面入力値を実行クラスに渡すためにセッションに設定します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            Session["paramOrderId"] = paramOrderId;
            Session["paramAmount"] = paramAmount;
            Session["paramWithCapture"] = paramWithCapture;
            Session["paramTermUrl"] = paramTermUrl;
            Session["paramCustomerIp"] = paramCustomerIp;


            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 実行＆結果画面を表示します
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            Response.Redirect("./AuthorizeExec.aspx", true);
        }
        /// <summary>
        /// 引数が数値であるかを確認。
        /// </summary>
        /// <param name="strNum">確認する文字列</param>
        /// <returns>数値の場合はtrueを返す</returns>
        private bool IsNumber(string strNum)
        {
            double dNullable;

            return double.TryParse(
                strNum,
                System.Globalization.NumberStyles.Any,
                null,
                out dNullable
            );
        }

        protected string GetIPAddress()
        {
            System.Web.HttpContext context = System.Web.HttpContext.Current;

            string ipAddress = context.Request.ServerVariables["HTTP_X_FORWARDED_FOR"];

            if (!string.IsNullOrEmpty(ipAddress))
            {
                string[] addresses = ipAddress.Split(',');
                if (addresses.Length != 0)
                {
                    return addresses[0];
                }
            }

            return context.Request.ServerVariables["REMOTE_ADDR"];
        }
    }
}
